@@ -731,7 +731,7 @@ void yf::CProxy::Handle::closedumpfile()
 {
     if ( dumpfile > -1 )
     {
-        if ( !close(dumpfile) ) {
+        if ( close(dumpfile) != 0 ) {
             int err = errno;
             dumpfile = -1;
             db("Failed to close the dumpfile. errno = " +
@@ -1822,7 +1822,22 @@ void yf::CProxy::process(mp::Package &package) const
             h.cookiebuf += "= HTTP response " + itoa(hres->code) + "\n";
             const char *location = z_HTTP_header_lookup(hres->headers, "Location");
             if (location)
+            {
                 h.cookiebuf += "Location: " + std::string(location) + "\n";
+                // Check we don't redirect to a https page, that goes wrong
+                if ( hres->code == 302 && strncmp(location,"https:",6) == 0 ) {
+                    Z_GDU *gdu_req = package.request().get();
+                    // we need to get a freshy request, the package has moved
+                    if (gdu_req && gdu_req->which == Z_GDU_HTTP_Request)
+                    {
+                        Z_HTTP_Request *hreq = gdu_req->u.HTTP_Request; 
+                        m_p->error_page(package, hreq, h, 400,
+                                    "Can not proxy HTTPS");
+                        h.closedumpfile();
+                        return;
+                    }
+                }
+            }
             
             m_p->response_cookies(h,hres);
             m_p->add_resp_cookie(h, hres);
